import { z } from 'zod';
export declare const DueDateSchema: z.ZodObject<z.objectUtil.extendShape<{
    isRecurring: z.ZodBoolean;
    string: z.ZodString;
    date: z.ZodString;
}, {
    datetime: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    timezone: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    lang: z.ZodOptional<z.ZodNullable<z.ZodString>>;
}>, "strip", z.ZodTypeAny, {
    string: string;
    isRecurring: boolean;
    date: string;
    datetime?: string | null | undefined;
    timezone?: string | null | undefined;
    lang?: string | null | undefined;
}, {
    string: string;
    isRecurring: boolean;
    date: string;
    datetime?: string | null | undefined;
    timezone?: string | null | undefined;
    lang?: string | null | undefined;
}>;
/**
 * Represents a due date for a task.
 * @see https://todoist.com/api/v1/docs#tag/Tasks/operation/get_tasks_api_v1_tasks_get
 */
export interface DueDate extends z.infer<typeof DueDateSchema> {
}
export declare const DurationSchema: z.ZodObject<{
    amount: z.ZodNumber;
    unit: z.ZodEnum<["minute", "day"]>;
}, "strip", z.ZodTypeAny, {
    amount: number;
    unit: "minute" | "day";
}, {
    amount: number;
    unit: "minute" | "day";
}>;
/**
 * Represents a duration for a task deadline.
 * @see https://todoist.com/api/v1/docs#tag/Tasks
 */
export interface Duration extends z.infer<typeof DurationSchema> {
}
export declare const DeadlineSchema: z.ZodObject<{
    date: z.ZodString;
    lang: z.ZodString;
}, "strip", z.ZodTypeAny, {
    date: string;
    lang: string;
}, {
    date: string;
    lang: string;
}>;
/**
 * Represents a task deadline.
 */
export interface Deadline extends z.infer<typeof DeadlineSchema> {
}
export declare const TaskSchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodString;
    userId: z.ZodString;
    projectId: z.ZodString;
    sectionId: z.ZodNullable<z.ZodString>;
    parentId: z.ZodNullable<z.ZodString>;
    addedByUid: z.ZodNullable<z.ZodString>;
    assignedByUid: z.ZodNullable<z.ZodString>;
    responsibleUid: z.ZodNullable<z.ZodString>;
    labels: z.ZodArray<z.ZodString, "many">;
    deadline: z.ZodNullable<z.ZodObject<{
        date: z.ZodString;
        lang: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        date: string;
        lang: string;
    }, {
        date: string;
        lang: string;
    }>>;
    duration: z.ZodNullable<z.ZodObject<{
        amount: z.ZodNumber;
        unit: z.ZodEnum<["minute", "day"]>;
    }, "strip", z.ZodTypeAny, {
        amount: number;
        unit: "minute" | "day";
    }, {
        amount: number;
        unit: "minute" | "day";
    }>>;
    checked: z.ZodBoolean;
    isDeleted: z.ZodBoolean;
    addedAt: z.ZodNullable<z.ZodString>;
    completedAt: z.ZodNullable<z.ZodString>;
    updatedAt: z.ZodNullable<z.ZodString>;
    due: z.ZodNullable<z.ZodObject<z.objectUtil.extendShape<{
        isRecurring: z.ZodBoolean;
        string: z.ZodString;
        date: z.ZodString;
    }, {
        datetime: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        timezone: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        lang: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }>, "strip", z.ZodTypeAny, {
        string: string;
        isRecurring: boolean;
        date: string;
        datetime?: string | null | undefined;
        timezone?: string | null | undefined;
        lang?: string | null | undefined;
    }, {
        string: string;
        isRecurring: boolean;
        date: string;
        datetime?: string | null | undefined;
        timezone?: string | null | undefined;
        lang?: string | null | undefined;
    }>>;
    priority: z.ZodNumber;
    childOrder: z.ZodNumber;
    content: z.ZodString;
    description: z.ZodString;
    noteCount: z.ZodNumber;
    dayOrder: z.ZodNumber;
    isCollapsed: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    labels: string[];
    id: string;
    userId: string;
    projectId: string;
    sectionId: string | null;
    parentId: string | null;
    addedByUid: string | null;
    assignedByUid: string | null;
    responsibleUid: string | null;
    deadline: {
        date: string;
        lang: string;
    } | null;
    duration: {
        amount: number;
        unit: "minute" | "day";
    } | null;
    checked: boolean;
    isDeleted: boolean;
    addedAt: string | null;
    completedAt: string | null;
    updatedAt: string | null;
    due: {
        string: string;
        isRecurring: boolean;
        date: string;
        datetime?: string | null | undefined;
        timezone?: string | null | undefined;
        lang?: string | null | undefined;
    } | null;
    priority: number;
    childOrder: number;
    content: string;
    description: string;
    noteCount: number;
    dayOrder: number;
    isCollapsed: boolean;
}, {
    labels: string[];
    id: string;
    userId: string;
    projectId: string;
    sectionId: string | null;
    parentId: string | null;
    addedByUid: string | null;
    assignedByUid: string | null;
    responsibleUid: string | null;
    deadline: {
        date: string;
        lang: string;
    } | null;
    duration: {
        amount: number;
        unit: "minute" | "day";
    } | null;
    checked: boolean;
    isDeleted: boolean;
    addedAt: string | null;
    completedAt: string | null;
    updatedAt: string | null;
    due: {
        string: string;
        isRecurring: boolean;
        date: string;
        datetime?: string | null | undefined;
        timezone?: string | null | undefined;
        lang?: string | null | undefined;
    } | null;
    priority: number;
    childOrder: number;
    content: string;
    description: string;
    noteCount: number;
    dayOrder: number;
    isCollapsed: boolean;
}>, {
    url: string;
    labels: string[];
    id: string;
    userId: string;
    projectId: string;
    sectionId: string | null;
    parentId: string | null;
    addedByUid: string | null;
    assignedByUid: string | null;
    responsibleUid: string | null;
    deadline: {
        date: string;
        lang: string;
    } | null;
    duration: {
        amount: number;
        unit: "minute" | "day";
    } | null;
    checked: boolean;
    isDeleted: boolean;
    addedAt: string | null;
    completedAt: string | null;
    updatedAt: string | null;
    due: {
        string: string;
        isRecurring: boolean;
        date: string;
        datetime?: string | null | undefined;
        timezone?: string | null | undefined;
        lang?: string | null | undefined;
    } | null;
    priority: number;
    childOrder: number;
    content: string;
    description: string;
    noteCount: number;
    dayOrder: number;
    isCollapsed: boolean;
}, {
    labels: string[];
    id: string;
    userId: string;
    projectId: string;
    sectionId: string | null;
    parentId: string | null;
    addedByUid: string | null;
    assignedByUid: string | null;
    responsibleUid: string | null;
    deadline: {
        date: string;
        lang: string;
    } | null;
    duration: {
        amount: number;
        unit: "minute" | "day";
    } | null;
    checked: boolean;
    isDeleted: boolean;
    addedAt: string | null;
    completedAt: string | null;
    updatedAt: string | null;
    due: {
        string: string;
        isRecurring: boolean;
        date: string;
        datetime?: string | null | undefined;
        timezone?: string | null | undefined;
        lang?: string | null | undefined;
    } | null;
    priority: number;
    childOrder: number;
    content: string;
    description: string;
    noteCount: number;
    dayOrder: number;
    isCollapsed: boolean;
}>;
/**
 * Represents a task in Todoist.
 * @see https://todoist.com/api/v1/docs#tag/Tasks
 */
export interface Task extends z.infer<typeof TaskSchema> {
}
/**
 * Base schema for all project types in Todoist.
 * Contains common fields shared between personal and workspace projects.
 */
export declare const BaseProjectSchema: z.ZodObject<{
    id: z.ZodString;
    canAssignTasks: z.ZodBoolean;
    childOrder: z.ZodNumber;
    color: z.ZodString;
    createdAt: z.ZodNullable<z.ZodString>;
    isArchived: z.ZodBoolean;
    isDeleted: z.ZodBoolean;
    isFavorite: z.ZodBoolean;
    isFrozen: z.ZodBoolean;
    name: z.ZodString;
    updatedAt: z.ZodNullable<z.ZodString>;
    viewStyle: z.ZodString;
    defaultOrder: z.ZodNumber;
    description: z.ZodString;
    isCollapsed: z.ZodBoolean;
    isShared: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    id: string;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
}, {
    id: string;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
}>;
/**
 * Schema for personal projects in Todoist.
 */
export declare const PersonalProjectSchema: z.ZodEffects<z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodString;
    canAssignTasks: z.ZodBoolean;
    childOrder: z.ZodNumber;
    color: z.ZodString;
    createdAt: z.ZodNullable<z.ZodString>;
    isArchived: z.ZodBoolean;
    isDeleted: z.ZodBoolean;
    isFavorite: z.ZodBoolean;
    isFrozen: z.ZodBoolean;
    name: z.ZodString;
    updatedAt: z.ZodNullable<z.ZodString>;
    viewStyle: z.ZodString;
    defaultOrder: z.ZodNumber;
    description: z.ZodString;
    isCollapsed: z.ZodBoolean;
    isShared: z.ZodBoolean;
}, {
    parentId: z.ZodNullable<z.ZodString>;
    inboxProject: z.ZodBoolean;
}>, "strip", z.ZodTypeAny, {
    id: string;
    parentId: string | null;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
    inboxProject: boolean;
}, {
    id: string;
    parentId: string | null;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
    inboxProject: boolean;
}>, {
    url: string;
    id: string;
    parentId: string | null;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
    inboxProject: boolean;
}, {
    id: string;
    parentId: string | null;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
    inboxProject: boolean;
}>;
/**
 * Schema for workspace projects in Todoist.
 */
export declare const WorkspaceProjectSchema: z.ZodEffects<z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodString;
    canAssignTasks: z.ZodBoolean;
    childOrder: z.ZodNumber;
    color: z.ZodString;
    createdAt: z.ZodNullable<z.ZodString>;
    isArchived: z.ZodBoolean;
    isDeleted: z.ZodBoolean;
    isFavorite: z.ZodBoolean;
    isFrozen: z.ZodBoolean;
    name: z.ZodString;
    updatedAt: z.ZodNullable<z.ZodString>;
    viewStyle: z.ZodString;
    defaultOrder: z.ZodNumber;
    description: z.ZodString;
    isCollapsed: z.ZodBoolean;
    isShared: z.ZodBoolean;
}, {
    collaboratorRoleDefault: z.ZodString;
    folderId: z.ZodNullable<z.ZodBoolean>;
    isInviteOnly: z.ZodNullable<z.ZodBoolean>;
    isLinkSharingEnabled: z.ZodBoolean;
    role: z.ZodNullable<z.ZodString>;
    status: z.ZodString;
    workspaceId: z.ZodString;
}>, "strip", z.ZodTypeAny, {
    status: string;
    id: string;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
    collaboratorRoleDefault: string;
    folderId: boolean | null;
    isInviteOnly: boolean | null;
    isLinkSharingEnabled: boolean;
    role: string | null;
    workspaceId: string;
}, {
    status: string;
    id: string;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
    collaboratorRoleDefault: string;
    folderId: boolean | null;
    isInviteOnly: boolean | null;
    isLinkSharingEnabled: boolean;
    role: string | null;
    workspaceId: string;
}>, {
    url: string;
    status: string;
    id: string;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
    collaboratorRoleDefault: string;
    folderId: boolean | null;
    isInviteOnly: boolean | null;
    isLinkSharingEnabled: boolean;
    role: string | null;
    workspaceId: string;
}, {
    status: string;
    id: string;
    isDeleted: boolean;
    updatedAt: string | null;
    childOrder: number;
    description: string;
    isCollapsed: boolean;
    canAssignTasks: boolean;
    color: string;
    createdAt: string | null;
    isArchived: boolean;
    isFavorite: boolean;
    isFrozen: boolean;
    name: string;
    viewStyle: string;
    defaultOrder: number;
    isShared: boolean;
    collaboratorRoleDefault: string;
    folderId: boolean | null;
    isInviteOnly: boolean | null;
    isLinkSharingEnabled: boolean;
    role: string | null;
    workspaceId: string;
}>;
/**
 * Represents a personal project in Todoist.
 * @see https://todoist.com/api/v1/docs#tag/Projects
 */
export interface PersonalProject extends z.infer<typeof PersonalProjectSchema> {
}
/**
 * Represents a workspace project in Todoist.
 * @see https://todoist.com/api/v1/docs#tag/Projects
 */
export interface WorkspaceProject extends z.infer<typeof WorkspaceProjectSchema> {
}
/**
 * @see https://todoist.com/api/v1/docs#tag/Projects
 */
export type ProjectViewStyle = 'list' | 'board' | 'calendar';
export declare const SectionSchema: z.ZodObject<{
    id: z.ZodString;
    userId: z.ZodString;
    projectId: z.ZodString;
    addedAt: z.ZodString;
    updatedAt: z.ZodString;
    archivedAt: z.ZodNullable<z.ZodString>;
    name: z.ZodString;
    sectionOrder: z.ZodNumber;
    isArchived: z.ZodBoolean;
    isDeleted: z.ZodBoolean;
    isCollapsed: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    id: string;
    userId: string;
    projectId: string;
    isDeleted: boolean;
    addedAt: string;
    updatedAt: string;
    isCollapsed: boolean;
    isArchived: boolean;
    name: string;
    archivedAt: string | null;
    sectionOrder: number;
}, {
    id: string;
    userId: string;
    projectId: string;
    isDeleted: boolean;
    addedAt: string;
    updatedAt: string;
    isCollapsed: boolean;
    isArchived: boolean;
    name: string;
    archivedAt: string | null;
    sectionOrder: number;
}>;
/**
 * Represents a section in a Todoist project.
 * @see https://todoist.com/api/v1/docs#tag/Sections
 */
export interface Section extends z.infer<typeof SectionSchema> {
}
export declare const LabelSchema: z.ZodObject<{
    id: z.ZodString;
    order: z.ZodNullable<z.ZodNumber>;
    name: z.ZodString;
    color: z.ZodString;
    isFavorite: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    id: string;
    color: string;
    isFavorite: boolean;
    name: string;
    order: number | null;
}, {
    id: string;
    color: string;
    isFavorite: boolean;
    name: string;
    order: number | null;
}>;
/**
 * Represents a label in Todoist.
 * @see https://todoist.com/api/v1/docs#tag/Labels
 */
export interface Label extends z.infer<typeof LabelSchema> {
}
export declare const AttachmentSchema: z.ZodObject<z.objectUtil.extendShape<{
    resourceType: z.ZodString;
}, {
    fileName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    fileSize: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    fileType: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    fileUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    fileDuration: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    uploadState: z.ZodOptional<z.ZodNullable<z.ZodEnum<["pending", "completed"]>>>;
    image: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    imageWidth: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    imageHeight: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    url: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    title: z.ZodOptional<z.ZodNullable<z.ZodString>>;
}>, "strip", z.ZodTypeAny, {
    resourceType: string;
    url?: string | null | undefined;
    fileName?: string | null | undefined;
    fileSize?: number | null | undefined;
    fileType?: string | null | undefined;
    fileUrl?: string | null | undefined;
    fileDuration?: number | null | undefined;
    uploadState?: "pending" | "completed" | null | undefined;
    image?: string | null | undefined;
    imageWidth?: number | null | undefined;
    imageHeight?: number | null | undefined;
    title?: string | null | undefined;
}, {
    resourceType: string;
    url?: string | null | undefined;
    fileName?: string | null | undefined;
    fileSize?: number | null | undefined;
    fileType?: string | null | undefined;
    fileUrl?: string | null | undefined;
    fileDuration?: number | null | undefined;
    uploadState?: "pending" | "completed" | null | undefined;
    image?: string | null | undefined;
    imageWidth?: number | null | undefined;
    imageHeight?: number | null | undefined;
    title?: string | null | undefined;
}>;
/**
 * Represents a file attachment in a comment.
 * @see https://todoist.com/api/v1/docs#tag/Sync/Comments/File-Attachments
 */
export interface Attachment extends z.infer<typeof AttachmentSchema> {
}
export declare const RawCommentSchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodString;
    itemId: z.ZodOptional<z.ZodString>;
    projectId: z.ZodOptional<z.ZodString>;
    content: z.ZodString;
    postedAt: z.ZodString;
    fileAttachment: z.ZodNullable<z.ZodObject<z.objectUtil.extendShape<{
        resourceType: z.ZodString;
    }, {
        fileName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        fileSize: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        fileType: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        fileUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        fileDuration: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        uploadState: z.ZodOptional<z.ZodNullable<z.ZodEnum<["pending", "completed"]>>>;
        image: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        imageWidth: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        imageHeight: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        url: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        title: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }>, "strip", z.ZodTypeAny, {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    }, {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    }>>;
    postedUid: z.ZodString;
    uidsToNotify: z.ZodNullable<z.ZodArray<z.ZodString, "many">>;
    reactions: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>;
    isDeleted: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
    itemId?: string | undefined;
}, {
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
    itemId?: string | undefined;
}>, {
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
    itemId?: string | undefined;
}, {
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
    itemId?: string | undefined;
}>;
/**
 * Represents a raw comment response from the API.
 * @see https://todoist.com/api/v1/docs#tag/Comments
 */
export interface RawComment extends z.infer<typeof RawCommentSchema> {
}
export declare const CommentSchema: z.ZodEffects<z.ZodEffects<z.ZodObject<{
    id: z.ZodString;
    itemId: z.ZodOptional<z.ZodString>;
    projectId: z.ZodOptional<z.ZodString>;
    content: z.ZodString;
    postedAt: z.ZodString;
    fileAttachment: z.ZodNullable<z.ZodObject<z.objectUtil.extendShape<{
        resourceType: z.ZodString;
    }, {
        fileName: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        fileSize: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        fileType: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        fileUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        fileDuration: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        uploadState: z.ZodOptional<z.ZodNullable<z.ZodEnum<["pending", "completed"]>>>;
        image: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        imageWidth: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        imageHeight: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        url: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        title: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }>, "strip", z.ZodTypeAny, {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    }, {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    }>>;
    postedUid: z.ZodString;
    uidsToNotify: z.ZodNullable<z.ZodArray<z.ZodString, "many">>;
    reactions: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodString, "many">>>;
    isDeleted: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
    itemId?: string | undefined;
}, {
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
    itemId?: string | undefined;
}>, {
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
    itemId?: string | undefined;
}, {
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
    itemId?: string | undefined;
}>, {
    taskId: string | undefined;
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
}, {
    id: string;
    isDeleted: boolean;
    content: string;
    postedAt: string;
    fileAttachment: {
        resourceType: string;
        url?: string | null | undefined;
        fileName?: string | null | undefined;
        fileSize?: number | null | undefined;
        fileType?: string | null | undefined;
        fileUrl?: string | null | undefined;
        fileDuration?: number | null | undefined;
        uploadState?: "pending" | "completed" | null | undefined;
        image?: string | null | undefined;
        imageWidth?: number | null | undefined;
        imageHeight?: number | null | undefined;
        title?: string | null | undefined;
    } | null;
    postedUid: string;
    uidsToNotify: string[] | null;
    reactions: Record<string, string[]> | null;
    projectId?: string | undefined;
    itemId?: string | undefined;
}>;
/**
 * Represents a comment in Todoist.
 * @see https://todoist.com/api/v1/docs#tag/Comments
 */
export interface Comment extends z.infer<typeof CommentSchema> {
}
export declare const UserSchema: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    email: z.ZodString;
}, "strip", z.ZodTypeAny, {
    id: string;
    name: string;
    email: string;
}, {
    id: string;
    name: string;
    email: string;
}>;
/**
 * Represents a user in Todoist.
 * @see https://todoist.com/api/v1/docs#tag/User
 */
export interface User extends z.infer<typeof UserSchema> {
}
export declare const ColorSchema: z.ZodObject<{
    /** @deprecated No longer used */
    id: z.ZodNumber;
    /** The key of the color (i.e. 'berry_red') */
    key: z.ZodString;
    /** The display name of the color (i.e. 'Berry Red') */
    displayName: z.ZodString;
    /** @deprecated Use {@link Color.displayName} instead */
    name: z.ZodString;
    /** The hex value of the color (i.e. '#b8255f') */
    hexValue: z.ZodString;
    /**
     * @deprecated Use {@link Color.hexValue} instead
     */
    value: z.ZodString;
}, "strip", z.ZodTypeAny, {
    value: string;
    id: number;
    name: string;
    key: string;
    displayName: string;
    hexValue: string;
}, {
    value: string;
    id: number;
    name: string;
    key: string;
    displayName: string;
    hexValue: string;
}>;
/**
 * Represents a color in Todoist.
 * @see https://todoist.com/api/v1/docs#tag/Colors
 */
export interface Color extends z.infer<typeof ColorSchema> {
}
