import { type Task, type Section, type Label, type Comment, type User, type WorkspaceProject, type PersonalProject } from '../types/entities';
export declare function validateTask(input: unknown): Task;
export declare function validateTaskArray(input: unknown[]): Task[];
/**
 * Type guard to check if a project is a workspace project.
 * @param project The project to check
 * @returns True if the project is a workspace project
 */
export declare function isWorkspaceProject(project: PersonalProject | WorkspaceProject): project is WorkspaceProject;
/**
 * Type guard to check if a project is a personal project.
 * @param project The project to check
 * @returns True if the project is a personal project
 */
export declare function isPersonalProject(project: PersonalProject | WorkspaceProject): project is PersonalProject;
/**
 * Validates and parses a project input.
 * @param input The input to validate
 * @returns A validated project (either PersonalProject or WorkspaceProject)
 */
export declare function validateProject(input: unknown): PersonalProject | WorkspaceProject;
export declare function validateProjectArray(input: unknown[]): (PersonalProject | WorkspaceProject)[];
export declare function validateSection(input: unknown): Section;
export declare function validateSectionArray(input: unknown[]): Section[];
export declare function validateLabel(input: unknown): Label;
export declare function validateLabelArray(input: unknown[]): Label[];
export declare function validateComment(input: unknown): Comment;
export declare function validateCommentArray(input: unknown[]): Comment[];
export declare function validateUser(input: unknown): User;
export declare function validateUserArray(input: unknown[]): User[];
