"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateUserArray = exports.validateUser = exports.validateCommentArray = exports.validateComment = exports.validateLabelArray = exports.validateLabel = exports.validateSectionArray = exports.validateSection = exports.validateProjectArray = exports.validateProject = exports.isPersonalProject = exports.isWorkspaceProject = exports.validateTaskArray = exports.validateTask = void 0;
var entities_1 = require("../types/entities");
function validateTask(input) {
    return entities_1.TaskSchema.parse(input);
}
exports.validateTask = validateTask;
function validateTaskArray(input) {
    return input.map(validateTask);
}
exports.validateTaskArray = validateTaskArray;
/**
 * Type guard to check if a project is a workspace project.
 * @param project The project to check
 * @returns True if the project is a workspace project
 */
function isWorkspaceProject(project) {
    return 'workspaceId' in project;
}
exports.isWorkspaceProject = isWorkspaceProject;
/**
 * Type guard to check if a project is a personal project.
 * @param project The project to check
 * @returns True if the project is a personal project
 */
function isPersonalProject(project) {
    return !isWorkspaceProject(project);
}
exports.isPersonalProject = isPersonalProject;
/**
 * Validates and parses a project input.
 * @param input The input to validate
 * @returns A validated project (either PersonalProject or WorkspaceProject)
 */
function validateProject(input) {
    if ('workspaceId' in input) {
        return entities_1.WorkspaceProjectSchema.parse(input);
    }
    return entities_1.PersonalProjectSchema.parse(input);
}
exports.validateProject = validateProject;
function validateProjectArray(input) {
    return input.map(validateProject);
}
exports.validateProjectArray = validateProjectArray;
function validateSection(input) {
    return entities_1.SectionSchema.parse(input);
}
exports.validateSection = validateSection;
function validateSectionArray(input) {
    return input.map(validateSection);
}
exports.validateSectionArray = validateSectionArray;
function validateLabel(input) {
    return entities_1.LabelSchema.parse(input);
}
exports.validateLabel = validateLabel;
function validateLabelArray(input) {
    return input.map(validateLabel);
}
exports.validateLabelArray = validateLabelArray;
function validateComment(input) {
    return entities_1.CommentSchema.parse(input);
}
exports.validateComment = validateComment;
function validateCommentArray(input) {
    return input.map(validateComment);
}
exports.validateCommentArray = validateCommentArray;
function validateUser(input) {
    return entities_1.UserSchema.parse(input);
}
exports.validateUser = validateUser;
function validateUserArray(input) {
    return input.map(validateUser);
}
exports.validateUserArray = validateUserArray;
